@@ -23,7 +23,6 @@
 #include <config.h>
 #endif
 
-#define _GNU_SOURCE
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -1504,7 +1503,17 @@ static void isi_dial(struct ofono_voicecall *ovc,
 static void isi_answer(struct ofono_voicecall *ovc, ofono_voicecall_cb_t cb,
 			void *data)
 {
-	isi_call_answer_req(ovc, CALL_ID_ALL, cb, data);
+	struct isi_voicecall *ivc = ofono_voicecall_get_data(ovc);
+	int id;
+
+	for (id = 1; id <= 7; id++)
+		if (ivc->calls[id].status == CALL_STATUS_MT_ALERTING)
+			goto answer_by_id;
+
+	id = CALL_ID_ALL;
+
+answer_by_id:
+	isi_call_answer_req(ovc, id, cb, data);
 }
 
 static void isi_hangup_current(struct ofono_voicecall *ovc,
@@ -1705,7 +1714,7 @@ static void isi_release_specific(struct ofono_voicecall *ovc, int id,
 
 		if ((status->mode_info & CALL_MODE_ORIGINATOR))
 			cause = CALL_CAUSE_BUSY_USER_REQUEST;
-			break;
+		break;
 	}
 
 	isi_call_release_req(ovc, id, CALL_CAUSE_TYPE_CLIENT, cause, cb, data);
@@ -1925,7 +1934,7 @@ static void isi_remove(struct ofono_voicecall *call)
 	g_free(data);
 }
 
-static struct ofono_voicecall_driver driver = {
+static const struct ofono_voicecall_driver driver = {
 	.name			= "isimodem",
 	.probe			= isi_probe,
 	.remove			= isi_remove,
